@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2016 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2017 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -137,6 +137,12 @@ def message_warning(text):
     message.warning(text)
 
 
+@cmdutils.register(hide=True)
+def clear_messages():
+    """Clear all message notifications."""
+    message.global_bridge.clear_messages.emit()
+
+
 @cmdutils.register(debug=True)
 @cmdutils.argument('typ', choices=['exception', 'segfault'])
 def debug_crash(typ='exception'):
@@ -222,7 +228,7 @@ def debug_pyeval(s, quiet=False):
     else:
         tabbed_browser = objreg.get('tabbed-browser', scope='window',
                                     window='last-focused')
-        tabbed_browser.openurl(QUrl('qute:pyeval'), newtab=True)
+        tabbed_browser.openurl(QUrl('qute://pyeval'), newtab=True)
 
 
 @cmdutils.register(debug=True)
@@ -287,15 +293,24 @@ def debug_log_filter(filters: str):
     """Change the log filter for console logging.
 
     Args:
-        filters: A comma separated list of logger names.
+        filters: A comma separated list of logger names. Can also be "none" to
+                 clear any existing filters.
     """
-    if set(filters.split(',')).issubset(log.LOGGER_NAMES):
-        log.console_filter.names = filters.split(',')
-    else:
+    if log.console_filter is None:
+        raise cmdexc.CommandError("No log.console_filter. Not attached "
+                                  "to a console?")
+
+    if filters.strip().lower() == 'none':
+        log.console_filter.names = None
+        return
+
+    if not set(filters.split(',')).issubset(log.LOGGER_NAMES):
         raise cmdexc.CommandError("filters: Invalid value {} - expected one "
                                   "of: {}".format(filters,
                                                   ', '.join(log.LOGGER_NAMES)))
 
+    log.console_filter.names = filters.split(',')
+
 
 @cmdutils.register()
 @cmdutils.argument('current_win_id', win_id=True)
