@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2016 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2017 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -36,6 +36,10 @@ import contextlib
 from PyQt5.QtCore import (qVersion, QEventLoop, QDataStream, QByteArray,
                           QIODevice, QSaveFile, QT_VERSION_STR)
 from PyQt5.QtWidgets import QApplication
+try:
+    from PyQt5.QtWebKit import qWebKitVersion
+except ImportError:  # pragma: no cover
+    qWebKitVersion = None
 
 from qutebrowser.utils import log
 
@@ -80,31 +84,30 @@ class QtOSError(OSError):
             self.qt_errno = None
 
 
-def version_check(version, op=operator.ge, strict=False):
+def version_check(version, exact=False, strict=False):
     """Check if the Qt runtime version is the version supplied or newer.
 
     Args:
         version: The version to check against.
-        op: The operator to use for the check.
+        exact: if given, check with == instead of >=
         strict: If given, also check the compiled Qt version.
     """
-    if strict:
-        assert op in [operator.ge, operator.lt], op
+    # Catch code using the old API for this
+    assert exact not in [operator.gt, operator.lt, operator.ge, operator.le,
+                         operator.eq], exact
     parsed = pkg_resources.parse_version(version)
+    op = operator.eq if exact else operator.ge
     result = op(pkg_resources.parse_version(qVersion()), parsed)
-    if ((strict and op == operator.ge and result) or
-            (strict and op == operator.lt and not result)):
+    if strict and result:
+        # v1 ==/>= parsed, now check if v2 ==/>= parsed too.
         result = op(pkg_resources.parse_version(QT_VERSION_STR), parsed)
     return result
 
 
-def is_qtwebkit_ng(version):
-    """Check if the given version is  QtWebKit-NG.
-
-    This is typically used as is_webkit_ng(qWebKitVersion) but we don't want to
-    have QtWebKit imports in here.
-    """
-    return (pkg_resources.parse_version(version) >
+def is_qtwebkit_ng():
+    """Check if the given version is QtWebKit-NG."""
+    assert qWebKitVersion is not None
+    return (pkg_resources.parse_version(qWebKitVersion()) >
             pkg_resources.parse_version('538.1'))
 
 
@@ -160,7 +163,10 @@ def get_args(namespace):
 def check_print_compat():
     """Check if printing should work in the given Qt version."""
     # WORKAROUND (remove this when we bump the requirements to 5.3.0)
-    return not (os.name == 'nt' and version_check('5.3.0', operator.lt))
+    if os.name == 'nt':
+        return version_check('5.3')
+    else:
+        return True
 
 
 def ensure_valid(obj):
@@ -169,12 +175,6 @@ def ensure_valid(obj):
         raise QtValueError(obj)
 
 
-def ensure_not_null(obj):
-    """Ensure a Qt object with an .isNull() method is not null."""
-    if obj.isNull():
-        raise QtValueError(obj, null=True)
-
-
 def check_qdatastream(stream):
     """Check the status of a QDataStream and raise OSError if it's not ok."""
     status_to_str = {
@@ -407,15 +407,12 @@ class QtValueError(ValueError):
 
     """Exception which gets raised by ensure_valid."""
 
-    def __init__(self, obj, null=False):
+    def __init__(self, obj):
         try:
             self.reason = obj.errorString()
         except AttributeError:
             self.reason = None
-        if null:
-            err = "{} is null".format(obj)
-        else:
-            err = "{} is not valid".format(obj)
+        err = "{} is not valid".format(obj)
         if self.reason:
             err += ": {}".format(self.reason)
         super().__init__(err)
